# Graph Garden
Python library for managing ArangoDB instance

[ArangoDB](https://www.arangodb.com/) is a trademark and property of ArangoDB, Inc. Graph Garden library is just a convenient way of managing ArangoDB instance from CLI and Python code (setup, start, stop). It is not developed or endorsed by ArangoDB, Inc.

## Installation

```bash
pip install graph-garden
```

## Usage

Run the following command to get help:

```bash
graph-garden --help
```

You can also see how Graph Garden is currently used in [ConceptNet Rocks!](https://github.com/ldtoolkit/conceptnet-rocks).
